diff --git a/interface/resources/qml/LoginDialog/LinkAccountBody.qml b/interface/resources/qml/LoginDialog/LinkAccountBody.qml
index 00980b0876..dbe4235cdd 100644
--- a/interface/resources/qml/LoginDialog/LinkAccountBody.qml
+++ b/interface/resources/qml/LoginDialog/LinkAccountBody.qml
@@ -136,7 +136,7 @@ Item {
TextField {
id: usernameField
- text: Settings.getValue("wallet/savedUsername", "");
+ text: Settings.getValue("keepMeLoggedIn/savedUsername", "");
width: parent.width
focus: true
placeholderText: "Username or Email"
@@ -165,7 +165,7 @@ Item {
root.text = "";
}
Component.onCompleted: {
- var savedUsername = Settings.getValue("wallet/savedUsername", "");
+ var savedUsername = Settings.getValue("keepMeLoggedIn/savedUsername", "");
usernameField.text = savedUsername === "Unknown user" ? "" : savedUsername;
}
}
@@ -239,7 +239,10 @@ Item {
}
- Keys.onReturnPressed: linkAccountBody.login()
+ Keys.onReturnPressed: {
+ Settings.setValue("keepMeLoggedIn/savedUsername", usernameField.text);
+ linkAccountBody.login();
+ }
}
InfoItem {
@@ -263,21 +266,21 @@ Item {
CheckBox {
id: autoLogoutCheckbox
- checked: !Settings.getValue("wallet/autoLogout", true)
- text: "Keep me signed in"
+ checked: Settings.getValue("keepMeLoggedIn", false)
+ text: "Keep me logged in"
boxSize: 20;
labelFontSize: 15
color: hifi.colors.black
onCheckedChanged: {
- Settings.setValue("wallet/autoLogout", !checked);
+ Settings.setValue("keepMeLoggedIn", checked);
if (checked) {
- Settings.setValue("wallet/savedUsername", Account.username);
+ Settings.setValue("keepMeLoggedIn/savedUsername", usernameField.text);
} else {
- Settings.setValue("wallet/savedUsername", "");
+ Settings.setValue("keepMeLoggedIn/savedUsername", "");
}
}
Component.onDestruction: {
- Settings.setValue("wallet/autoLogout", !checked);
+ Settings.setValue("keepMeLoggedIn", checked);
}
}
@@ -289,7 +292,10 @@ Item {
text: qsTr(loginDialog.isSteamRunning() ? "Link Account" : "Log in")
color: hifi.buttons.blue
- onClicked: linkAccountBody.login()
+ onClicked: {
+ Settings.setValue("keepMeLoggedIn/savedUsername", usernameField.text);
+ linkAccountBody.login();
+ }
}
}
@@ -403,6 +409,7 @@ Item {
case Qt.Key_Enter:
case Qt.Key_Return:
event.accepted = true
+ Settings.setValue("keepMeLoggedIn/savedUsername", usernameField.text);
linkAccountBody.login()
break
}
diff --git a/interface/resources/qml/hifi/commerce/common/CommerceLightbox.qml b/interface/resources/qml/hifi/commerce/common/CommerceLightbox.qml
index 9d9216c461..5901adc484 100644
--- a/interface/resources/qml/hifi/commerce/common/CommerceLightbox.qml
+++ b/interface/resources/qml/hifi/commerce/common/CommerceLightbox.qml
@@ -14,9 +14,9 @@
import Hifi 1.0 as Hifi
import QtQuick 2.5
import QtGraphicalEffects 1.0
-import "../../../styles-uit"
-import "../../../controls-uit" as HifiControlsUit
-import "../../../controls" as HifiControls
+import "qrc:////qml//styles-uit"
+import "qrc:////qml//controls-uit" as HifiControlsUit
+import "qrc:////qml//controls" as HifiControls
// references XXX from root context
@@ -33,13 +33,15 @@ Rectangle {
property string buttonLayout: "leftright";
readonly property string securityPicBodyText: "When you see your Security Pic, your actions and data are securely making use of your " +
- "Wallet's private keys.
You can change your Security Pic in your Wallet.";
+ "private keys.
You can change your Security Pic via Settings > Security...";
id: root;
visible: false;
anchors.fill: parent;
color: Qt.rgba(0, 0, 0, 0.5);
z: 999;
+
+ HifiConstants { id: hifi; }
onVisibleChanged: {
if (!visible) {
diff --git a/interface/resources/qml/hifi/commerce/wallet/Help.qml b/interface/resources/qml/hifi/commerce/wallet/Help.qml
index 6d8fc3c33f..6cf00f78eb 100644
--- a/interface/resources/qml/hifi/commerce/wallet/Help.qml
+++ b/interface/resources/qml/hifi/commerce/wallet/Help.qml
@@ -74,8 +74,7 @@ In your Wallet's Send Money tab, choose from your list of connections, or choose
isExpanded: false;
question: "What is a Security Pic?"
answer: "Your Security Pic acts as an extra layer of Wallet security. \
-When you see your Security Pic, you know that your actions and data are securely making use of your account. \
-
Tap here to change your Security Pic.";
+When you see your Security Pic, you know that your actions and data are securely making use of your account.";
}
ListElement {
isExpanded: false;
@@ -137,7 +136,7 @@ At the moment, there is currently no way to convert HFC to other currencies. Sta
anchors.left: parent.left;
width: parent.width;
height: questionText.paintedHeight + 50;
-
+
RalewaySemiBold {
id: plusMinusButton;
text: model.isExpanded ? "-" : "+";
@@ -217,8 +216,6 @@ At the moment, there is currently no way to convert HFC to other currencies. Sta
}
} else if (link === "#support") {
Qt.openUrlExternally("mailto:support@highfidelity.com");
- } else if (link === "#securitypic") {
- sendSignalToWallet({method: 'walletSecurity_changeSecurityImage'});
}
}
}
diff --git a/interface/resources/qml/hifi/commerce/wallet/Security.qml b/interface/resources/qml/hifi/commerce/wallet/Security.qml
deleted file mode 100644
index 14ac696ef7..0000000000
--- a/interface/resources/qml/hifi/commerce/wallet/Security.qml
+++ /dev/null
@@ -1,246 +0,0 @@
-//
-// Security.qml
-// qml/hifi/commerce/wallet
-//
-// Security
-//
-// Created by Zach Fox on 2017-08-18
-// Copyright 2017 High Fidelity, Inc.
-//
-// Distributed under the Apache License, Version 2.0.
-// See the accompanying file LICENSE or http://www.apache.org/licenses/LICENSE-2.0.html
-//
-
-import Hifi 1.0 as Hifi
-import QtQuick 2.5
-import QtGraphicalEffects 1.0
-import "../../../styles-uit"
-import "../../../controls-uit" as HifiControlsUit
-import "../../../controls" as HifiControls
-
-// references XXX from root context
-
-Item {
- HifiConstants { id: hifi; }
-
- id: root;
- property string keyFilePath;
-
- Connections {
- target: Commerce;
-
- onKeyFilePathIfExistsResult: {
- root.keyFilePath = path;
- }
- }
-
- // Username Text
- RalewayRegular {
- id: usernameText;
- text: Account.username;
- // Text size
- size: 24;
- // Style
- color: hifi.colors.white;
- elide: Text.ElideRight;
- // Anchors
- anchors.top: parent.top;
- anchors.left: parent.left;
- anchors.leftMargin: 20;
- width: parent.width/2;
- height: 80;
- }
-
- Item {
- id: securityContainer;
- anchors.top: usernameText.bottom;
- anchors.topMargin: 20;
- anchors.left: parent.left;
- anchors.right: parent.right;
- anchors.bottom: parent.bottom;
-
- RalewaySemiBold {
- id: securityText;
- text: "Security";
- // Anchors
- anchors.top: parent.top;
- anchors.left: parent.left;
- anchors.leftMargin: 20;
- anchors.right: parent.right;
- height: 30;
- // Text size
- size: 18;
- // Style
- color: hifi.colors.blueHighlight;
- }
-
- Rectangle {
- id: securityTextSeparator;
- // Size
- width: parent.width;
- height: 1;
- // Anchors
- anchors.left: parent.left;
- anchors.right: parent.right;
- anchors.top: securityText.bottom;
- anchors.topMargin: 8;
- // Style
- color: hifi.colors.faintGray;
- }
-
- Item {
- id: changeSecurityImageContainer;
- anchors.top: securityTextSeparator.bottom;
- anchors.topMargin: 8;
- anchors.left: parent.left;
- anchors.leftMargin: 40;
- anchors.right: parent.right;
- anchors.rightMargin: 55;
- height: 75;
-
- HiFiGlyphs {
- id: changeSecurityImageImage;
- text: hifi.glyphs.securityImage;
- // Size
- size: 80;
- // Anchors
- anchors.top: parent.top;
- anchors.bottom: parent.bottom;
- anchors.left: parent.left;
- // Style
- color: hifi.colors.white;
- }
-
- RalewaySemiBold {
- text: "Security Pic";
- // Anchors
- anchors.top: parent.top;
- anchors.bottom: parent.bottom;
- anchors.left: changeSecurityImageImage.right;
- anchors.leftMargin: 30;
- width: 50;
- // Text size
- size: 18;
- // Style
- color: hifi.colors.white;
- }
-
- // "Change Security Pic" button
- HifiControlsUit.Button {
- id: changeSecurityImageButton;
- color: hifi.buttons.blue;
- colorScheme: hifi.colorSchemes.dark;
- anchors.right: parent.right;
- anchors.verticalCenter: parent.verticalCenter;
- width: 140;
- height: 40;
- text: "Change";
- onClicked: {
- sendSignalToWallet({method: 'walletSecurity_changeSecurityImage'});
- }
- }
- }
-
- Item {
- id: autoLogoutContainer;
- anchors.top: changeSecurityImageContainer.bottom;
- anchors.topMargin: 8;
- anchors.left: parent.left;
- anchors.leftMargin: 40;
- anchors.right: parent.right;
- anchors.rightMargin: 55;
- height: 75;
-
- HiFiGlyphs {
- id: autoLogoutImage;
- text: hifi.glyphs.walletKey;
- // Size
- size: 80;
- // Anchors
- anchors.top: parent.top;
- anchors.topMargin: 20;
- anchors.left: parent.left;
- // Style
- color: hifi.colors.white;
- }
-
- HifiControlsUit.CheckBox {
- id: autoLogoutCheckbox;
- checked: Settings.getValue("wallet/autoLogout", false);
- text: "Automatically Log Out when Exiting Interface"
- // Anchors
- anchors.verticalCenter: autoLogoutImage.verticalCenter;
- anchors.left: autoLogoutImage.right;
- anchors.leftMargin: 20;
- anchors.right: autoLogoutHelp.left;
- anchors.rightMargin: 12;
- boxSize: 28;
- labelFontSize: 18;
- color: hifi.colors.white;
- onCheckedChanged: {
- Settings.setValue("wallet/autoLogout", checked);
- if (checked) {
- Settings.setValue("wallet/savedUsername", Account.username);
- } else {
- Settings.setValue("wallet/savedUsername", "");
- }
- }
- }
-
- RalewaySemiBold {
- id: autoLogoutHelp;
- text: '[?]';
- // Anchors
- anchors.verticalCenter: autoLogoutImage.verticalCenter;
- anchors.right: parent.right;
- width: 30;
- height: 30;
- // Text size
- size: 18;
- // Style
- color: hifi.colors.blueHighlight;
-
- MouseArea {
- anchors.fill: parent;
- hoverEnabled: true;
- onEntered: {
- parent.color = hifi.colors.blueAccent;
- }
- onExited: {
- parent.color = hifi.colors.blueHighlight;
- }
- onClicked: {
- sendSignalToWallet({method: 'walletSecurity_autoLogoutHelp'});
- }
- }
- }
- }
- }
-
- //
- // FUNCTION DEFINITIONS START
- //
- //
- // Function Name: fromScript()
- //
- // Relevant Variables:
- // None
- //
- // Arguments:
- // message: The message sent from the JavaScript.
- // Messages are in format "{method, params}", like json-rpc.
- //
- // Description:
- // Called when a message is received from a script.
- //
- function fromScript(message) {
- switch (message.method) {
- default:
- console.log('Unrecognized message from wallet.js:', JSON.stringify(message));
- }
- }
- signal sendSignalToWallet(var msg);
- //
- // FUNCTION DEFINITIONS END
- //
-}
diff --git a/interface/resources/qml/hifi/commerce/wallet/Wallet.qml b/interface/resources/qml/hifi/commerce/wallet/Wallet.qml
index e17faef194..d882ef8d38 100644
--- a/interface/resources/qml/hifi/commerce/wallet/Wallet.qml
+++ b/interface/resources/qml/hifi/commerce/wallet/Wallet.qml
@@ -160,7 +160,7 @@ Rectangle {
Image {
id: titleBarSecurityImage;
source: "";
- visible: titleBarSecurityImage.source !== "" && !securityImageChange.visible;
+ visible: titleBarSecurityImage.source !== "";
anchors.right: parent.right;
anchors.rightMargin: 6;
anchors.top: parent.top;
@@ -250,10 +250,6 @@ Rectangle {
root.isPassword = msg.isPasswordField;
} else if (msg.method === 'walletSetup_lowerKeyboard') {
root.keyboardRaised = false;
- } else if (msg.method === 'walletSecurity_changePassphraseCancelled') {
- root.activeView = "security";
- } else if (msg.method === 'walletSecurity_changePassphraseSuccess') {
- root.activeView = "security";
} else {
sendToScript(msg);
}
@@ -263,27 +259,6 @@ Rectangle {
}
}
}
- SecurityImageChange {
- id: securityImageChange;
- visible: root.activeView === "securityImageChange";
- z: 997;
- anchors.top: titleBarContainer.bottom;
- anchors.left: parent.left;
- anchors.right: parent.right;
- anchors.bottom: parent.bottom;
-
- Connections {
- onSendSignalToWallet: {
- if (msg.method === 'walletSecurity_changeSecurityImageCancelled') {
- root.activeView = "security";
- } else if (msg.method === 'walletSecurity_changeSecurityImageSuccess') {
- root.activeView = "security";
- } else {
- sendToScript(msg);
- }
- }
- }
- }
//
// TAB CONTENTS START
@@ -417,39 +392,6 @@ Rectangle {
}
}
- Security {
- id: security;
- visible: root.activeView === "security";
- anchors.top: titleBarContainer.bottom;
- anchors.bottom: tabButtonsContainer.top;
- anchors.left: parent.left;
- anchors.right: parent.right;
-
- Connections {
- onSendSignalToWallet: {
- if (msg.method === 'walletSecurity_changePassphrase') {
- root.activeView = "passphraseChange";
- passphraseChange.clearPassphraseFields();
- passphraseChange.resetSubmitButton();
- } else if (msg.method === 'walletSecurity_changeSecurityImage') {
- securityImageChange.initModel();
- root.activeView = "securityImageChange";
- } else if (msg.method === 'walletSecurity_autoLogoutHelp') {
- lightboxPopup.titleText = "Automatically Log Out";
- lightboxPopup.bodyText = "By default, after you log in to High Fidelity, you will stay logged in to your High Fidelity " +
- "account even after you close and re-open Interface. This means anyone who opens Interface on your computer " +
- "could make purchases with your HFC.\n\n" +
- "If you do not want to stay logged in across Interface sessions, check this box.";
- lightboxPopup.button1text = "CLOSE";
- lightboxPopup.button1method = function() {
- lightboxPopup.visible = false;
- }
- lightboxPopup.visible = true;
- }
- }
- }
- }
-
Help {
id: help;
visible: root.activeView === "help";
@@ -458,14 +400,6 @@ Rectangle {
anchors.left: parent.left;
anchors.right: parent.right;
- Connections {
- onSendSignalToWallet: {
- if (msg.method === 'walletSecurity_changeSecurityImage') {
- securityImageChange.initModel();
- root.activeView = "securityImageChange";
- }
- }
- }
}
@@ -478,8 +412,8 @@ Rectangle {
//
Item {
id: tabButtonsContainer;
- visible: !needsLogIn.visible && root.activeView !== "passphraseChange" && root.activeView !== "securityImageChange" && sendMoney.currentActiveView !== "sendAssetStep";
- property int numTabs: 5;
+ visible: !needsLogIn.visible && root.activeView !== "passphraseChange" && sendMoney.currentActiveView !== "sendAssetStep";
+ property int numTabs: 4;
// Size
width: root.width;
height: 90;
@@ -690,60 +624,6 @@ Rectangle {
}
}
- // "SECURITY" tab button
- Rectangle {
- id: securityButtonContainer;
- visible: !walletSetup.visible;
- color: root.activeView === "security" ? hifi.colors.blueAccent : hifi.colors.black;
- anchors.top: parent.top;
- anchors.left: sendMoneyButtonContainer.right;
- anchors.bottom: parent.bottom;
- width: parent.width / tabButtonsContainer.numTabs;
-
- HiFiGlyphs {
- id: securityTabIcon;
- text: hifi.glyphs.lock;
- // Size
- size: 38;
- // Anchors
- anchors.horizontalCenter: parent.horizontalCenter;
- anchors.top: parent.top;
- anchors.topMargin: 2;
- // Style
- color: root.activeView === "security" || securityTabMouseArea.containsMouse ? hifi.colors.white : hifi.colors.blueHighlight;
- }
-
- RalewaySemiBold {
- text: "SECURITY";
- // Text size
- size: 16;
- // Anchors
- anchors.bottom: parent.bottom;
- height: parent.height/2;
- anchors.left: parent.left;
- anchors.leftMargin: 4;
- anchors.right: parent.right;
- anchors.rightMargin: 4;
- // Style
- color: root.activeView === "security" || securityTabMouseArea.containsMouse ? hifi.colors.white : hifi.colors.blueHighlight;
- wrapMode: Text.WordWrap;
- // Alignment
- horizontalAlignment: Text.AlignHCenter;
- verticalAlignment: Text.AlignTop;
- }
- MouseArea {
- id: securityTabMouseArea;
- anchors.fill: parent;
- hoverEnabled: enabled;
- onClicked: {
- root.activeView = "security";
- tabButtonsContainer.resetTabButtonColors();
- }
- onEntered: parent.color = hifi.colors.blueHighlight;
- onExited: parent.color = root.activeView === "security" ? hifi.colors.blueAccent : hifi.colors.black;
- }
- }
-
// "HELP" tab button
Rectangle {
id: helpButtonContainer;
diff --git a/interface/resources/qml/hifi/commerce/wallet/WalletSetup.qml b/interface/resources/qml/hifi/commerce/wallet/WalletSetup.qml
index dc6ce45a74..ecd7234400 100644
--- a/interface/resources/qml/hifi/commerce/wallet/WalletSetup.qml
+++ b/interface/resources/qml/hifi/commerce/wallet/WalletSetup.qml
@@ -243,7 +243,6 @@ Item {
height: 50;
text: "Set Up Wallet";
onClicked: {
- securityImageSelection.initModel();
root.activeView = "step_2";
}
}
@@ -267,124 +266,6 @@ Item {
// FIRST PAGE END
//
- //
- // SECURITY IMAGE SELECTION START
- //
- Item {
- id: securityImageContainer;
- visible: root.activeView === "step_2";
- // Anchors
- anchors.top: titleBarContainer.bottom;
- anchors.topMargin: 30;
- anchors.bottom: parent.bottom;
- anchors.left: parent.left;
- anchors.leftMargin: 16;
- anchors.right: parent.right;
- anchors.rightMargin: 16;
-
- // Text below title bar
- RalewayRegular {
- id: securityImageTitleHelper;
- text: "Choose a Security Pic:";
- // Text size
- size: 24;
- // Anchors
- anchors.top: parent.top;
- anchors.left: parent.left;
- height: 50;
- width: paintedWidth;
- // Style
- color: hifi.colors.white;
- // Alignment
- horizontalAlignment: Text.AlignHLeft;
- verticalAlignment: Text.AlignVCenter;
- }
-
- SecurityImageSelection {
- id: securityImageSelection;
- // Anchors
- anchors.top: securityImageTitleHelper.bottom;
- anchors.left: parent.left;
- anchors.right: parent.right;
- height: 300;
-
- Connections {
- onSendSignalToWallet: {
- sendSignalToWallet(msg);
- }
- }
- }
-
- // Text below security images
- RalewayRegular {
- text: "Your security picture shows you that the service asking for your passphrase is authorized. You can change your secure picture at any time.";
- // Text size
- size: 18;
- // Anchors
- anchors.top: securityImageSelection.bottom;
- anchors.topMargin: 40;
- anchors.left: parent.left;
- anchors.right: parent.right;
- height: paintedHeight;
- // Style
- color: hifi.colors.white;
- wrapMode: Text.WordWrap;
- // Alignment
- horizontalAlignment: Text.AlignHLeft;
- verticalAlignment: Text.AlignVCenter;
- }
-
- // Navigation Bar
- Item {
- // Size
- width: parent.width;
- height: 50;
- // Anchors:
- anchors.left: parent.left;
- anchors.bottom: parent.bottom;
- anchors.bottomMargin: 50;
-
- // "Back" button
- HifiControlsUit.Button {
- color: hifi.buttons.noneBorderlessWhite;
- colorScheme: hifi.colorSchemes.dark;
- anchors.top: parent.top;
- anchors.bottom: parent.bottom;
- anchors.left: parent.left;
- anchors.leftMargin: 20;
- width: 200;
- text: "Back"
- onClicked: {
- securityImageSelection.resetSelection();
- root.activeView = "step_1";
- }
- }
-
- // "Next" button
- HifiControlsUit.Button {
- enabled: securityImageSelection.currentIndex !== -1;
- color: hifi.buttons.blue;
- colorScheme: hifi.colorSchemes.dark;
- anchors.top: parent.top;
- anchors.bottom: parent.bottom;
- anchors.right: parent.right;
- anchors.rightMargin: 20;
- width: 200;
- text: "Next";
- onClicked: {
- root.lastPage = "step_2";
- var securityImagePath = securityImageSelection.getImagePathFromImageID(securityImageSelection.getSelectedImageIndex())
- Commerce.chooseSecurityImage(securityImagePath);
- root.activeView = "step_3";
- passphraseSelection.clearPassphraseFields();
- }
- }
- }
- }
- //
- // SECURITY IMAGE SELECTION END
- //
-
//
// SECURE PASSPHRASE SELECTION START
//
@@ -525,7 +406,6 @@ Item {
width: 200;
text: "Back"
onClicked: {
- securityImageSelection.resetSelection();
root.lastPage = "step_3";
root.activeView = "step_2";
}
diff --git a/interface/resources/qml/hifi/dialogs/security/Security.qml b/interface/resources/qml/hifi/dialogs/security/Security.qml
new file mode 100644
index 0000000000..8baff0ac13
--- /dev/null
+++ b/interface/resources/qml/hifi/dialogs/security/Security.qml
@@ -0,0 +1,344 @@
+//
+// Security.qml
+// qml\hifi\dialogs\security
+//
+// Security
+//
+// Created by Zach Fox on 2018-10-31
+// Copyright 2018 High Fidelity, Inc.
+//
+// Distributed under the Apache License, Version 2.0.
+// See the accompanying file LICENSE or http://www.apache.org/licenses/LICENSE-2.0.html
+//
+
+import Hifi 1.0 as Hifi
+import QtQuick 2.5
+import QtGraphicalEffects 1.0
+import "qrc:////qml//styles-uit" as HifiStylesUit
+import "qrc:////qml//controls-uit" as HifiControlsUit
+import "qrc:////qml//controls" as HifiControls
+import "qrc:////qml//hifi//commerce//common" as HifiCommerceCommon
+
+Rectangle {
+ HifiStylesUit.HifiConstants { id: hifi; }
+
+ id: root;
+ color: hifi.colors.baseGray;
+
+ property string title: "Security Settings";
+ property bool walletSetUp;
+
+ QtObject {
+ id: margins
+ property real paddings: root.width / 20.25
+
+ property real sizeCheckBox: root.width / 13.5
+ property real sizeText: root.width / 2.5
+ property real sizeLevel: root.width / 5.8
+ property real sizeDesktop: root.width / 5.8
+ property real sizeVR: root.width / 13.5
+ }
+
+ Connections {
+ target: Commerce;
+
+ onWalletStatusResult: {
+ if (walletStatus === 5) {
+ Commerce.getSecurityImage();
+ root.walletSetUp = true;
+ } else {
+ root.walletSetUp = false;
+ }
+ }
+
+ onSecurityImageResult: {
+ if (exists) {
+ currentSecurityPicture.source = "";
+ currentSecurityPicture.source = "image://security/securityImage";
+ }
+ }
+ }
+
+ Component.onCompleted: {
+ Commerce.getWalletStatus();
+ }
+
+ HifiCommerceCommon.CommerceLightbox {
+ z: 996;
+ id: lightboxPopup;
+ visible: false;
+ anchors.fill: parent;
+ }
+
+ SecurityImageChange {
+ id: securityImageChange;
+ visible: false;
+ z: 997;
+ anchors.top: usernameText.bottom;
+ anchors.left: parent.left;
+ anchors.right: parent.right;
+ anchors.bottom: parent.bottom;
+
+ Connections {
+ onSendSignalToParent: {
+ securityImageChange.visible = false;
+ }
+ }
+ }
+
+ // Username Text
+ HifiStylesUit.RalewayRegular {
+ id: usernameText;
+ text: Account.username === "Unknown user" ? "Please Log In" : Account.username;
+ // Text size
+ size: 24;
+ // Style
+ color: hifi.colors.white;
+ elide: Text.ElideRight;
+ // Anchors
+ anchors.top: parent.top;
+ anchors.left: parent.left;
+ anchors.leftMargin: 20;
+ anchors.right: parent.right;
+ anchors.rightMargin: 20;
+ height: 60;
+ }
+
+ Item {
+ id: pleaseLogInContainer;
+ visible: Account.username === "Unknown user";
+ anchors.top: usernameText.bottom;
+ anchors.left: parent.left;
+ anchors.right: parent.right;
+ anchors.bottom: parent.bottom;
+
+ HifiStylesUit.RalewayRegular {
+ text: "Please log in for security settings."
+ // Text size
+ size: 24;
+ // Style
+ color: hifi.colors.white;
+ // Anchors
+ anchors.bottom: openLoginButton.top;
+ anchors.left: parent.left;
+ anchors.right: parent.right;
+ horizontalAlignment: Text.AlignHCenter;
+ verticalAlignment: Text.AlignVCenter;
+ height: 60;
+ }
+
+ HifiControlsUit.Button {
+ id: openLoginButton;
+ color: hifi.buttons.white;
+ colorScheme: hifi.colorSchemes.dark;
+ anchors.centerIn: parent;
+ width: 140;
+ height: 40;
+ text: "Log In";
+ onClicked: {
+ DialogsManager.showLoginDialog();
+ }
+ }
+ }
+
+ Item {
+ id: securitySettingsContainer;
+ visible: !pleaseLogInContainer.visible;
+ anchors.top: usernameText.bottom;
+ anchors.left: parent.left;
+ anchors.right: parent.right;
+ anchors.bottom: parent.bottom;
+
+ Item {
+ id: accountContainer;
+ anchors.top: securitySettingsContainer.top;
+ anchors.left: parent.left;
+ anchors.right: parent.right;
+ height: childrenRect.height;
+
+ Rectangle {
+ id: accountHeaderContainer;
+ anchors.top: parent.top;
+ anchors.left: parent.left;
+ anchors.right: parent.right;
+ height: 55;
+ color: hifi.colors.baseGrayHighlight;
+
+ HifiStylesUit.RalewaySemiBold {
+ text: "Account";
+ anchors.fill: parent;
+ anchors.leftMargin: 20;
+ color: hifi.colors.white;
+ size: 18;
+ }
+ }
+
+ Item {
+ id: keepMeLoggedInContainer;
+ anchors.top: accountHeaderContainer.bottom;
+ anchors.left: parent.left;
+ anchors.right: parent.right;
+ height: 80;
+
+ HifiControlsUit.CheckBox {
+ id: autoLogoutCheckbox;
+ checked: Settings.getValue("keepMeLoggedIn", false);
+ text: "Keep Me Logged In"
+ // Anchors
+ anchors.verticalCenter: parent.verticalCenter;
+ anchors.left: parent.left;
+ anchors.leftMargin: 20;
+ boxSize: 24;
+ labelFontSize: 18;
+ colorScheme: hifi.colorSchemes.dark
+ color: hifi.colors.white;
+ width: 240;
+ onCheckedChanged: {
+ Settings.setValue("keepMeLoggedIn", checked);
+ if (checked) {
+ Settings.setValue("keepMeLoggedIn/savedUsername", Account.username);
+ } else {
+ Settings.setValue("keepMeLoggedIn/savedUsername", "");
+ }
+ }
+ }
+
+ HifiStylesUit.RalewaySemiBold {
+ id: autoLogoutHelp;
+ text: '[?]';
+ // Anchors
+ anchors.verticalCenter: parent.verticalCenter;
+ anchors.right: autoLogoutCheckbox.right;
+ width: 30;
+ height: 30;
+ // Text size
+ size: 18;
+ // Style
+ color: hifi.colors.blueHighlight;
+
+ MouseArea {
+ anchors.fill: parent;
+ hoverEnabled: true;
+ onEntered: {
+ parent.color = hifi.colors.blueAccent;
+ }
+ onExited: {
+ parent.color = hifi.colors.blueHighlight;
+ }
+ onClicked: {
+ lightboxPopup.titleText = "Keep Me Logged In";
+ lightboxPopup.bodyText = "If you choose to stay logged in, ensure that this is a trusted device.\n\n" +
+ "Also, remember that logging out may not disconnect you from a domain.";
+ lightboxPopup.button1text = "OK";
+ lightboxPopup.button1method = function() {
+ lightboxPopup.visible = false;
+ }
+ lightboxPopup.visible = true;
+ }
+ }
+ }
+ }
+ }
+
+ Item {
+ id: walletContainer;
+ anchors.top: accountContainer.bottom;
+ anchors.left: parent.left;
+ anchors.right: parent.right;
+ height: childrenRect.height;
+
+ Rectangle {
+ id: walletHeaderContainer;
+ anchors.top: parent.top;
+ anchors.left: parent.left;
+ anchors.right: parent.right;
+ height: 55;
+ color: hifi.colors.baseGrayHighlight;
+
+ HifiStylesUit.RalewaySemiBold {
+ text: "Wallet";
+ anchors.fill: parent;
+ anchors.leftMargin: 20;
+ color: hifi.colors.white;
+ size: 18;
+ }
+ }
+
+ Item {
+ id: walletSecurityPictureContainer;
+ visible: root.walletSetUp;
+ anchors.top: walletHeaderContainer.bottom;
+ anchors.left: parent.left;
+ anchors.right: parent.right;
+ height: 80;
+
+ Image {
+ id: currentSecurityPicture;
+ source: "";
+ visible: true;
+ anchors.left: parent.left;
+ anchors.leftMargin: 20;
+ anchors.verticalCenter: parent.verticalCenter;
+ height: 40;
+ width: height;
+ mipmap: true;
+ cache: false;
+ }
+
+ HifiStylesUit.RalewaySemiBold {
+ id: securityPictureText;
+ text: "Wallet Security Picture";
+ // Anchors
+ anchors.top: parent.top;
+ anchors.bottom: parent.bottom;
+ anchors.left: currentSecurityPicture.right;
+ anchors.leftMargin: 12;
+ width: paintedWidth;
+ // Text size
+ size: 18;
+ // Style
+ color: hifi.colors.white;
+ }
+
+ // "Change Security Pic" button
+ HifiControlsUit.Button {
+ id: changeSecurityImageButton;
+ color: hifi.buttons.white;
+ colorScheme: hifi.colorSchemes.dark;
+ anchors.left: securityPictureText.right;
+ anchors.leftMargin: 12;
+ anchors.verticalCenter: parent.verticalCenter;
+ width: 140;
+ height: 40;
+ text: "Change";
+ onClicked: {
+ securityImageChange.visible = true;
+ securityImageChange.initModel();
+ }
+ }
+ }
+
+ Item {
+ id: walletNotSetUpContainer;
+ visible: !root.walletSetUp;
+ anchors.top: walletHeaderContainer.bottom;
+ anchors.left: parent.left;
+ anchors.right: parent.right;
+ height: 60;
+
+ HifiStylesUit.RalewayRegular {
+ text: "Your wallet is not set up.\n" +
+ "Open the WALLET app to get started.";
+ // Anchors
+ anchors.fill: parent;
+ // Text size
+ size: 18;
+ // Style
+ color: hifi.colors.white;
+ horizontalAlignment: Text.AlignHCenter;
+ verticalAlignment: Text.AlignVCenter;
+ }
+ }
+ }
+ }
+}
diff --git a/interface/resources/qml/hifi/commerce/wallet/SecurityImageChange.qml b/interface/resources/qml/hifi/dialogs/security/SecurityImageChange.qml
similarity index 88%
rename from interface/resources/qml/hifi/commerce/wallet/SecurityImageChange.qml
rename to interface/resources/qml/hifi/dialogs/security/SecurityImageChange.qml
index 01df18352b..96d75e340b 100644
--- a/interface/resources/qml/hifi/commerce/wallet/SecurityImageChange.qml
+++ b/interface/resources/qml/hifi/dialogs/security/SecurityImageChange.qml
@@ -1,11 +1,11 @@
//
// SecurityImageChange.qml
-// qml/hifi/commerce/wallet
+// qml\hifi\dialogs\security
//
-// SecurityImageChange
+// Security
//
-// Created by Zach Fox on 2017-08-18
-// Copyright 2017 High Fidelity, Inc.
+// Created by Zach Fox on 2018-10-31
+// Copyright 2018 High Fidelity, Inc.
//
// Distributed under the Apache License, Version 2.0.
// See the accompanying file LICENSE or http://www.apache.org/licenses/LICENSE-2.0.html
@@ -13,16 +13,17 @@
import Hifi 1.0 as Hifi
import QtQuick 2.5
-import "../../../styles-uit"
-import "../../../controls-uit" as HifiControlsUit
-import "../../../controls" as HifiControls
+import "qrc:////qml//styles-uit" as HifiStylesUit
+import "qrc:////qml//controls-uit" as HifiControlsUit
+import "qrc:////qml//controls" as HifiControls
// references XXX from root context
-Item {
- HifiConstants { id: hifi; }
+Rectangle {
+ HifiStylesUit.HifiConstants { id: hifi; }
id: root;
+ color: hifi.colors.baseGray;
property bool justSubmitted: false;
Connections {
@@ -33,7 +34,7 @@ Item {
securityImageChangePageSecurityImage.source = "image://security/securityImage";
if (exists) { // Success submitting new security image
if (root.justSubmitted) {
- sendSignalToWallet({method: "walletSecurity_changeSecurityImageSuccess"});
+ sendSignalToParent({method: "walletSecurity_changeSecurityImageSuccess"});
root.justSubmitted = false;
}
} else if (root.justSubmitted) {
@@ -72,7 +73,7 @@ Item {
anchors.bottom: parent.bottom;
height: 22;
// Lock icon
- HiFiGlyphs {
+ HifiStylesUit.HiFiGlyphs {
id: lockIcon;
text: hifi.glyphs.lock;
anchors.bottom: parent.bottom;
@@ -83,8 +84,8 @@ Item {
verticalAlignment: Text.AlignBottom;
color: hifi.colors.white;
}
- // "Security image" text below pic
- RalewayRegular {
+ // "Security image" text below image
+ HifiStylesUit.RalewayRegular {
id: securityImageText;
text: "SECURITY PIC";
// Text size
@@ -116,9 +117,9 @@ Item {
anchors.bottom: parent.bottom;
// "Change Security Image" text
- RalewaySemiBold {
+ HifiStylesUit.RalewaySemiBold {
id: securityImageTitle;
- text: "Change Security Pic:";
+ text: "Change Security Image:";
// Text size
size: 18;
anchors.top: parent.top;
@@ -139,12 +140,6 @@ Item {
anchors.right: parent.right;
anchors.rightMargin: 16;
height: 300;
-
- Connections {
- onSendSignalToWallet: {
- sendSignalToWallet(msg);
- }
- }
}
// Navigation Bar
@@ -169,7 +164,7 @@ Item {
width: 150;
text: "Cancel"
onClicked: {
- sendSignalToWallet({method: "walletSecurity_changeSecurityImageCancelled"});
+ sendSignalToParent({method: "walletSecurity_changeSecurityImageCancelled"});
}
}
@@ -197,7 +192,7 @@ Item {
// SECURITY IMAGE SELECTION END
//
- signal sendSignalToWallet(var msg);
+ signal sendSignalToParent(var msg);
function initModel() {
securityImageSelection.initModel();
diff --git a/interface/resources/qml/hifi/commerce/wallet/SecurityImageModel.qml b/interface/resources/qml/hifi/dialogs/security/SecurityImageModel.qml
similarity index 89%
rename from interface/resources/qml/hifi/commerce/wallet/SecurityImageModel.qml
rename to interface/resources/qml/hifi/dialogs/security/SecurityImageModel.qml
index b8e9db09ab..946f979c1a 100644
--- a/interface/resources/qml/hifi/commerce/wallet/SecurityImageModel.qml
+++ b/interface/resources/qml/hifi/dialogs/security/SecurityImageModel.qml
@@ -1,11 +1,11 @@
//
// SecurityImageModel.qml
-// qml/hifi/commerce
+// qml\hifi\dialogs\security
//
-// SecurityImageModel
+// Security
//
-// Created by Zach Fox on 2017-08-17
-// Copyright 2017 High Fidelity, Inc.
+// Created by Zach Fox on 2018-10-31
+// Copyright 2018 High Fidelity, Inc.
//
// Distributed under the Apache License, Version 2.0.
// See the accompanying file LICENSE or http://www.apache.org/licenses/LICENSE-2.0.html
diff --git a/interface/resources/qml/hifi/commerce/wallet/SecurityImageSelection.qml b/interface/resources/qml/hifi/dialogs/security/SecurityImageSelection.qml
similarity index 81%
rename from interface/resources/qml/hifi/commerce/wallet/SecurityImageSelection.qml
rename to interface/resources/qml/hifi/dialogs/security/SecurityImageSelection.qml
index 599c6a1851..f058aad40a 100644
--- a/interface/resources/qml/hifi/commerce/wallet/SecurityImageSelection.qml
+++ b/interface/resources/qml/hifi/dialogs/security/SecurityImageSelection.qml
@@ -1,11 +1,11 @@
//
// SecurityImageSelection.qml
-// qml/hifi/commerce/wallet
+// qml\hifi\dialogs\security
//
-// SecurityImageSelection
+// Security
//
-// Created by Zach Fox on 2017-08-17
-// Copyright 2017 High Fidelity, Inc.
+// Created by Zach Fox on 2018-10-31
+// Copyright 2018 High Fidelity, Inc.
//
// Distributed under the Apache License, Version 2.0.
// See the accompanying file LICENSE or http://www.apache.org/licenses/LICENSE-2.0.html
@@ -13,14 +13,14 @@
import Hifi 1.0 as Hifi
import QtQuick 2.5
-import "../../../styles-uit"
-import "../../../controls-uit" as HifiControlsUit
-import "../../../controls" as HifiControls
+import "qrc:////qml//styles-uit" as HifiStylesUit
+import "qrc:////qml//controls-uit" as HifiControlsUit
+import "qrc:////qml//controls" as HifiControls
// references XXX from root context
Item {
- HifiConstants { id: hifi; }
+ HifiStylesUit.HifiConstants { id: hifi; }
id: root;
property alias currentIndex: securityImageGrid.currentIndex;
@@ -64,17 +64,15 @@ Item {
}
}
highlight: Rectangle {
- width: securityImageGrid.cellWidth;
- height: securityImageGrid.cellHeight;
- color: hifi.colors.blueHighlight;
- }
+ width: securityImageGrid.cellWidth;
+ height: securityImageGrid.cellHeight;
+ color: hifi.colors.blueHighlight;
+ }
}
//
// FUNCTION DEFINITIONS START
//
- signal sendSignalToWallet(var msg);
-
function getImagePathFromImageID(imageID) {
return (imageID ? gridModel.getImagePathFromImageID(imageID) : "");
}
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/01.jpg b/interface/resources/qml/hifi/dialogs/security/images/01.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/01.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/01.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/02.jpg b/interface/resources/qml/hifi/dialogs/security/images/02.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/02.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/02.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/03.jpg b/interface/resources/qml/hifi/dialogs/security/images/03.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/03.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/03.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/04.jpg b/interface/resources/qml/hifi/dialogs/security/images/04.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/04.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/04.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/05.jpg b/interface/resources/qml/hifi/dialogs/security/images/05.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/05.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/05.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/06.jpg b/interface/resources/qml/hifi/dialogs/security/images/06.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/06.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/06.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/07.jpg b/interface/resources/qml/hifi/dialogs/security/images/07.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/07.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/07.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/08.jpg b/interface/resources/qml/hifi/dialogs/security/images/08.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/08.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/08.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/09.jpg b/interface/resources/qml/hifi/dialogs/security/images/09.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/09.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/09.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/10.jpg b/interface/resources/qml/hifi/dialogs/security/images/10.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/10.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/10.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/11.jpg b/interface/resources/qml/hifi/dialogs/security/images/11.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/11.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/11.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/12.jpg b/interface/resources/qml/hifi/dialogs/security/images/12.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/12.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/12.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/13.jpg b/interface/resources/qml/hifi/dialogs/security/images/13.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/13.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/13.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/14.jpg b/interface/resources/qml/hifi/dialogs/security/images/14.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/14.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/14.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/15.jpg b/interface/resources/qml/hifi/dialogs/security/images/15.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/15.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/15.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/16.jpg b/interface/resources/qml/hifi/dialogs/security/images/16.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/16.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/16.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/17.jpg b/interface/resources/qml/hifi/dialogs/security/images/17.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/17.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/17.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/18.jpg b/interface/resources/qml/hifi/dialogs/security/images/18.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/18.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/18.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/19.jpg b/interface/resources/qml/hifi/dialogs/security/images/19.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/19.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/19.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/20.jpg b/interface/resources/qml/hifi/dialogs/security/images/20.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/20.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/20.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/21.jpg b/interface/resources/qml/hifi/dialogs/security/images/21.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/21.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/21.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/22.jpg b/interface/resources/qml/hifi/dialogs/security/images/22.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/22.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/22.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/23.jpg b/interface/resources/qml/hifi/dialogs/security/images/23.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/23.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/23.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/24.jpg b/interface/resources/qml/hifi/dialogs/security/images/24.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/24.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/24.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/25.jpg b/interface/resources/qml/hifi/dialogs/security/images/25.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/25.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/25.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/26.jpg b/interface/resources/qml/hifi/dialogs/security/images/26.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/26.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/26.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/27.jpg b/interface/resources/qml/hifi/dialogs/security/images/27.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/27.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/27.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/28.jpg b/interface/resources/qml/hifi/dialogs/security/images/28.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/28.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/28.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/29.jpg b/interface/resources/qml/hifi/dialogs/security/images/29.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/29.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/29.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/30.jpg b/interface/resources/qml/hifi/dialogs/security/images/30.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/30.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/30.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/31.jpg b/interface/resources/qml/hifi/dialogs/security/images/31.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/31.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/31.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/32.jpg b/interface/resources/qml/hifi/dialogs/security/images/32.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/32.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/32.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/33.jpg b/interface/resources/qml/hifi/dialogs/security/images/33.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/33.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/33.jpg
diff --git a/interface/resources/qml/hifi/commerce/wallet/images/34.jpg b/interface/resources/qml/hifi/dialogs/security/images/34.jpg
similarity index 100%
rename from interface/resources/qml/hifi/commerce/wallet/images/34.jpg
rename to interface/resources/qml/hifi/dialogs/security/images/34.jpg
diff --git a/interface/src/Application.cpp b/interface/src/Application.cpp
index ff1822013b..c2faf8494a 100644
--- a/interface/src/Application.cpp
+++ b/interface/src/Application.cpp
@@ -382,7 +382,7 @@ static const int INTERVAL_TO_CHECK_HMD_WORN_STATUS = 500; // milliseconds
static const QString DESKTOP_DISPLAY_PLUGIN_NAME = "Desktop";
static const QString ACTIVE_DISPLAY_PLUGIN_SETTING_NAME = "activeDisplayPlugin";
static const QString SYSTEM_TABLET = "com.highfidelity.interface.tablet.system";
-static const QString AUTO_LOGOUT_SETTING_NAME = "wallet/autoLogout";
+static const QString KEEP_ME_LOGGED_IN_SETTING_NAME = "keepMeLoggedIn";
const std::vector> Application::_acceptedExtensions {
{ SVO_EXTENSION, &Application::importSVOFromURL },
@@ -2569,8 +2569,8 @@ void Application::cleanupBeforeQuit() {
}
DependencyManager::destroy();
- bool autoLogout = Setting::Handle(AUTO_LOGOUT_SETTING_NAME, false).get();
- if (autoLogout) {
+ bool keepMeLoggedIn = Setting::Handle(KEEP_ME_LOGGED_IN_SETTING_NAME, false).get();
+ if (!keepMeLoggedIn) {
DependencyManager::get()->removeAccountFromFile();
}
@@ -2946,13 +2946,13 @@ void Application::initializeUi() {
QUrl{ "hifi/commerce/wallet/PassphraseChange.qml" },
QUrl{ "hifi/commerce/wallet/PassphraseModal.qml" },
QUrl{ "hifi/commerce/wallet/PassphraseSelection.qml" },
- QUrl{ "hifi/commerce/wallet/Security.qml" },
- QUrl{ "hifi/commerce/wallet/SecurityImageChange.qml" },
- QUrl{ "hifi/commerce/wallet/SecurityImageModel.qml" },
- QUrl{ "hifi/commerce/wallet/SecurityImageSelection.qml" },
QUrl{ "hifi/commerce/wallet/Wallet.qml" },
QUrl{ "hifi/commerce/wallet/WalletHome.qml" },
QUrl{ "hifi/commerce/wallet/WalletSetup.qml" },
+ QUrl{ "hifi/dialogs/security/Security.qml" },
+ QUrl{ "hifi/dialogs/security/SecurityImageChange.qml" },
+ QUrl{ "hifi/dialogs/security/SecurityImageModel.qml" },
+ QUrl{ "hifi/dialogs/security/SecurityImageSelection.qml" },
}, callback);
qmlRegisterType("Hifi", 1, 0, "ResourceImageItem");
qmlRegisterType("Hifi", 1, 0, "Preference");
diff --git a/interface/src/Menu.cpp b/interface/src/Menu.cpp
index 539bdabe7d..16e8af5683 100644
--- a/interface/src/Menu.cpp
+++ b/interface/src/Menu.cpp
@@ -265,6 +265,18 @@ Menu::Menu() {
QString("hifi/tablet/TabletGraphicsPreferences.qml"), "GraphicsPreferencesDialog");
});
+ // Settings > Security...
+ action = addActionToQMenuAndActionHash(settingsMenu, "Security...");
+ connect(action, &QAction::triggered, [] {
+ auto tablet = DependencyManager::get()->getTablet("com.highfidelity.interface.tablet.system");
+ auto hmd = DependencyManager::get();
+ tablet->pushOntoStack("hifi/dialogs/security/Security.qml");
+
+ if (!hmd->getShouldShowTablet()) {
+ hmd->toggleShouldShowTablet();
+ }
+ });
+
// Settings > Developer Menu
addCheckableActionToQMenuAndActionHash(settingsMenu, "Developer Menu", 0, false, this, SLOT(toggleDeveloperMenus()));
diff --git a/interface/src/avatar/AvatarManager.cpp b/interface/src/avatar/AvatarManager.cpp
index dad4c44f4b..aa57336a3c 100644
--- a/interface/src/avatar/AvatarManager.cpp
+++ b/interface/src/avatar/AvatarManager.cpp
@@ -261,7 +261,9 @@ void AvatarManager::updateOtherAvatars(float deltaTime) {
for (auto it = sortedAvatarVector.begin(); it != sortedAvatarVector.end(); ++it) {
const SortableAvatar& sortData = *it;
const auto avatar = std::static_pointer_cast(sortData.getAvatar());
-
+ if (!avatar->_isClientAvatar) {
+ avatar->setIsClientAvatar(true);
+ }
// TODO: to help us scale to more avatars it would be nice to not have to poll this stuff every update
if (avatar->getSkeletonModel()->isLoaded()) {
// remove the orb if it is there
diff --git a/interface/src/commerce/Ledger.cpp b/interface/src/commerce/Ledger.cpp
index f4bd7a84b3..0c59fbc6d0 100644
--- a/interface/src/commerce/Ledger.cpp
+++ b/interface/src/commerce/Ledger.cpp
@@ -219,7 +219,11 @@ QString transactionString(const QJsonObject& valueObject) {
if (!message.isEmpty()) {
result += QString("
with memo: \"%1\"").arg(message);
}
- } else if (sentMoney <= 0 && receivedMoney <= 0 && (sentCerts > 0 || receivedCerts > 0) && !KNOWN_USERS.contains(valueObject["sender_name"].toString())) {
+ } else if (sentMoney <= 0 && receivedMoney <= 0 &&
+ (sentCerts > 0 || receivedCerts > 0) &&
+ !KNOWN_USERS.contains(valueObject["sender_name"].toString()) &&
+ !KNOWN_USERS.contains(valueObject["recipient_name"].toString())
+ ) {
// this is a non-HFC asset transfer.
if (sentCerts > 0) {
QString recipient = userLink(valueObject["recipient_name"].toString(), valueObject["place_name"].toString());
diff --git a/interface/src/commerce/Wallet.cpp b/interface/src/commerce/Wallet.cpp
index 5b8417be7c..0e9ad7d79a 100644
--- a/interface/src/commerce/Wallet.cpp
+++ b/interface/src/commerce/Wallet.cpp
@@ -687,7 +687,7 @@ void Wallet::chooseSecurityImage(const QString& filename) {
delete _securityImage;
}
QString path = PathUtils::resourcesPath();
- path.append("/qml/hifi/commerce/wallet/");
+ path.append("/qml/hifi/dialogs/security/");
path.append(filename);
// now create a new security image pixmap
diff --git a/libraries/audio-client/src/AudioClient.cpp b/libraries/audio-client/src/AudioClient.cpp
index d00bc29054..bdd6d0edc1 100644
--- a/libraries/audio-client/src/AudioClient.cpp
+++ b/libraries/audio-client/src/AudioClient.cpp
@@ -244,13 +244,20 @@ AudioClient::AudioClient() :
// initialize wasapi; if getAvailableDevices is called from the CheckDevicesThread before this, it will crash
getAvailableDevices(QAudio::AudioInput);
getAvailableDevices(QAudio::AudioOutput);
-
+
// start a thread to detect any device changes
_checkDevicesTimer = new QTimer(this);
- connect(_checkDevicesTimer, &QTimer::timeout, this, [this] {
- QtConcurrent::run(QThreadPool::globalInstance(), [this] { checkDevices(); });
- });
const unsigned long DEVICE_CHECK_INTERVAL_MSECS = 2 * 1000;
+ connect(_checkDevicesTimer, &QTimer::timeout, this, [=] {
+ QtConcurrent::run(QThreadPool::globalInstance(), [=] {
+ checkDevices();
+ // On some systems (Ubuntu) checking all the audio devices can take more than 2 seconds. To
+ // avoid consuming all of the thread pool, don't start the check interval until the previous
+ // check has completed.
+ QMetaObject::invokeMethod(_checkDevicesTimer, "start", Q_ARG(int, DEVICE_CHECK_INTERVAL_MSECS));
+ });
+ });
+ _checkDevicesTimer->setSingleShot(true);
_checkDevicesTimer->start(DEVICE_CHECK_INTERVAL_MSECS);
// start a thread to detect peak value changes
diff --git a/libraries/avatars-renderer/src/avatars-renderer/Avatar.cpp b/libraries/avatars-renderer/src/avatars-renderer/Avatar.cpp
index 86f5bd69a5..06dd498af3 100644
--- a/libraries/avatars-renderer/src/avatars-renderer/Avatar.cpp
+++ b/libraries/avatars-renderer/src/avatars-renderer/Avatar.cpp
@@ -498,8 +498,8 @@ void Avatar::relayJointDataToChildren() {
glm::quat jointRotation;
glm::vec3 jointTranslation;
if (avatarJointIndex < 0) {
- jointRotation = modelEntity->getAbsoluteJointRotationInObjectFrame(jointIndex);
- jointTranslation = modelEntity->getAbsoluteJointTranslationInObjectFrame(jointIndex);
+ jointRotation = modelEntity->getLocalJointRotation(jointIndex);
+ jointTranslation = modelEntity->getLocalJointTranslation(jointIndex);
map.push_back(-1);
} else {
int jointIndex = getJointIndex(jointName);
@@ -522,8 +522,8 @@ void Avatar::relayJointDataToChildren() {
jointRotation = getJointRotation(avatarJointIndex);
jointTranslation = getJointTranslation(avatarJointIndex);
} else {
- jointRotation = modelEntity->getAbsoluteJointRotationInObjectFrame(jointIndex);
- jointTranslation = modelEntity->getAbsoluteJointTranslationInObjectFrame(jointIndex);
+ jointRotation = modelEntity->getLocalJointRotation(jointIndex);
+ jointTranslation = modelEntity->getLocalJointTranslation(jointIndex);
}
modelEntity->setLocalJointRotation(jointIndex, jointRotation);
modelEntity->setLocalJointTranslation(jointIndex, jointTranslation);
diff --git a/libraries/avatars/src/AvatarData.cpp b/libraries/avatars/src/AvatarData.cpp
index 7f42289a9b..c529865b85 100644
--- a/libraries/avatars/src/AvatarData.cpp
+++ b/libraries/avatars/src/AvatarData.cpp
@@ -936,17 +936,27 @@ int AvatarData::parseDataFromBuffer(const QByteArray& buffer) {
}
_serverPosition = glm::vec3(data->globalPosition[0], data->globalPosition[1], data->globalPosition[2]) + offset;
- auto oneStepDistance = glm::length(_globalPosition - _serverPosition);
- if (oneStepDistance <= AVATAR_TRANSIT_MIN_TRIGGER_DISTANCE || oneStepDistance >= AVATAR_TRANSIT_MAX_TRIGGER_DISTANCE) {
- _globalPosition = _serverPosition;
- // if we don't have a parent, make sure to also set our local position
+ if (_isClientAvatar) {
+ auto oneStepDistance = glm::length(_globalPosition - _serverPosition);
+ if (oneStepDistance <= AVATAR_TRANSIT_MIN_TRIGGER_DISTANCE || oneStepDistance >= AVATAR_TRANSIT_MAX_TRIGGER_DISTANCE) {
+ _globalPosition = _serverPosition;
+ // if we don't have a parent, make sure to also set our local position
+ if (!hasParent()) {
+ setLocalPosition(_serverPosition);
+ }
+ }
+ if (_globalPosition != _serverPosition) {
+ _globalPositionChanged = now;
+ }
+ } else {
+ if (_globalPosition != _serverPosition) {
+ _globalPosition = _serverPosition;
+ _globalPositionChanged = now;
+ }
if (!hasParent()) {
setLocalPosition(_serverPosition);
}
}
- if (_globalPosition != _serverPosition) {
- _globalPositionChanged = now;
- }
sourceBuffer += sizeof(AvatarDataPacket::AvatarGlobalPosition);
int numBytesRead = sourceBuffer - startSection;
_globalPositionRate.increment(numBytesRead);
diff --git a/libraries/avatars/src/AvatarData.h b/libraries/avatars/src/AvatarData.h
index 8533f142bb..48593de212 100644
--- a/libraries/avatars/src/AvatarData.h
+++ b/libraries/avatars/src/AvatarData.h
@@ -1221,6 +1221,7 @@ public:
void setIsNewAvatar(bool isNewAvatar) { _isNewAvatar = isNewAvatar; }
bool getIsNewAvatar() { return _isNewAvatar; }
+ void setIsClientAvatar(bool isClientAvatar) { _isClientAvatar = isClientAvatar; }
signals:
@@ -1486,6 +1487,7 @@ protected:
float _density;
int _replicaIndex { 0 };
bool _isNewAvatar { true };
+ bool _isClientAvatar { false };
// null unless MyAvatar or ScriptableAvatar sending traits data to mixer
std::unique_ptr _clientTraitsHandler;
diff --git a/libraries/entities/src/EntityItemProperties.cpp b/libraries/entities/src/EntityItemProperties.cpp
index d901592759..c243f772e2 100644
--- a/libraries/entities/src/EntityItemProperties.cpp
+++ b/libraries/entities/src/EntityItemProperties.cpp
@@ -3207,6 +3207,8 @@ void EntityItemProperties::markAllChanged() {
_queryAACubeChanged = true;
+ _shapeChanged = true;
+
_flyingAllowedChanged = true;
_ghostingAllowedChanged = true;
_filterURLChanged = true;
diff --git a/libraries/networking/src/udt/CongestionControl.h b/libraries/networking/src/udt/CongestionControl.h
index 7093e8bd96..bfe7f552d1 100644
--- a/libraries/networking/src/udt/CongestionControl.h
+++ b/libraries/networking/src/udt/CongestionControl.h
@@ -45,8 +45,10 @@ public:
virtual void onTimeout() {}
virtual void onPacketSent(int wireSize, SequenceNumber seqNum, p_high_resolution_clock::time_point timePoint) {}
+ virtual void onPacketReSent(int wireSize, SequenceNumber seqNum, p_high_resolution_clock::time_point timePoint) {}
virtual int estimatedTimeout() const = 0;
+
protected:
void setMSS(int mss) { _mss = mss; }
virtual void setInitialSendSequenceNumber(SequenceNumber seqNum) = 0;
diff --git a/libraries/networking/src/udt/Connection.cpp b/libraries/networking/src/udt/Connection.cpp
index 24e294881a..4798288a18 100644
--- a/libraries/networking/src/udt/Connection.cpp
+++ b/libraries/networking/src/udt/Connection.cpp
@@ -195,7 +195,7 @@ void Connection::recordSentPackets(int wireSize, int payloadSize,
void Connection::recordRetransmission(int wireSize, SequenceNumber seqNum, p_high_resolution_clock::time_point timePoint) {
_stats.record(ConnectionStats::Stats::Retransmission);
- _congestionControl->onPacketSent(wireSize, seqNum, timePoint);
+ _congestionControl->onPacketReSent(wireSize, seqNum, timePoint);
}
void Connection::sendACK() {
@@ -303,7 +303,7 @@ void Connection::processControl(ControlPacketPointer controlPacket) {
// where the other end expired our connection. Let's reset.
#ifdef UDT_CONNECTION_DEBUG
- qCDebug(networking) << "Got HandshakeRequest from" << _destination << ", stopping SendQueue";
+ qCDebug(networking) << "Got HandshakeRequest from" << _destination << ", stopping SendQueue";
#endif
_hasReceivedHandshakeACK = false;
stopSendQueue();
@@ -327,19 +327,19 @@ void Connection::processACK(ControlPacketPointer controlPacket) {
return;
}
- if (ack <= _lastReceivedACK) {
+ if (ack < _lastReceivedACK) {
// this is an out of order ACK, bail
- // or
- // processing an already received ACK, bail
return;
}
-
- _lastReceivedACK = ack;
-
- // ACK the send queue so it knows what was received
- getSendQueue().ack(ack);
-
+ if (ack > _lastReceivedACK) {
+ // this is not a repeated ACK, so update our member and tell the send queue
+ _lastReceivedACK = ack;
+
+ // ACK the send queue so it knows what was received
+ getSendQueue().ack(ack);
+ }
+
// give this ACK to the congestion control and update the send queue parameters
updateCongestionControlAndSendQueue([this, ack, &controlPacket] {
if (_congestionControl->onACK(ack, controlPacket->getReceiveTime())) {
diff --git a/libraries/networking/src/udt/SendQueue.cpp b/libraries/networking/src/udt/SendQueue.cpp
index b1dfb9a8cf..9cba4970ac 100644
--- a/libraries/networking/src/udt/SendQueue.cpp
+++ b/libraries/networking/src/udt/SendQueue.cpp
@@ -481,6 +481,7 @@ bool SendQueue::isInactive(bool attemptedToSendPacket) {
auto cvStatus = _emptyCondition.wait_for(locker, EMPTY_QUEUES_INACTIVE_TIMEOUT);
if (cvStatus == std::cv_status::timeout && (_packets.isEmpty() || isFlowWindowFull()) && _naks.isEmpty()) {
+
#ifdef UDT_CONNECTION_DEBUG
qCDebug(networking) << "SendQueue to" << _destination << "has been empty for"
<< EMPTY_QUEUES_INACTIVE_TIMEOUT.count()
diff --git a/libraries/networking/src/udt/TCPVegasCC.cpp b/libraries/networking/src/udt/TCPVegasCC.cpp
index 4842e5a204..f2119237c2 100644
--- a/libraries/networking/src/udt/TCPVegasCC.cpp
+++ b/libraries/networking/src/udt/TCPVegasCC.cpp
@@ -27,112 +27,106 @@ TCPVegasCC::TCPVegasCC() {
_baseRTT = std::numeric_limits::max();
}
+bool TCPVegasCC::calculateRTT(p_high_resolution_clock::time_point sendTime, p_high_resolution_clock::time_point receiveTime) {
+ // calculate the RTT (receive time - time ACK sent)
+ int lastRTT = duration_cast(receiveTime - sendTime).count();
+
+ const int MAX_RTT_SAMPLE_MICROSECONDS = 10000000;
+
+ if (lastRTT < 0) {
+ Q_ASSERT_X(false, __FUNCTION__, "calculated an RTT that is not > 0");
+ return false;
+ } else if (lastRTT == 0) {
+ // we do not allow a zero microsecond RTT (as per the UNIX kernel implementation of TCP Vegas)
+ lastRTT = 1;
+ } else if (lastRTT > MAX_RTT_SAMPLE_MICROSECONDS) {
+ // we cap the lastRTT to MAX_RTT_SAMPLE_MICROSECONDS to avoid overflows in window size calculations
+ lastRTT = MAX_RTT_SAMPLE_MICROSECONDS;
+ }
+
+ if (_ewmaRTT == -1) {
+ // first RTT sample - set _ewmaRTT to the value and set the variance to half the value
+ _ewmaRTT = lastRTT;
+ _rttVariance = lastRTT / 2;
+ } else {
+ // This updates the RTT using exponential weighted moving average
+ // This is the Jacobson's forumla for RTT estimation
+ // http://www.mathcs.emory.edu/~cheung/Courses/455/Syllabus/7-transport/Jacobson-88.pdf
+
+ // Estimated RTT = (1 - x)(estimatedRTT) + (x)(sampleRTT)
+ // (where x = 0.125 via Jacobson)
+
+ // Deviation = (1 - x)(deviation) + x |sampleRTT - estimatedRTT|
+ // (where x = 0.25 via Jacobson)
+
+ static const int RTT_ESTIMATION_ALPHA = 8;
+ static const int RTT_ESTIMATION_VARIANCE_ALPHA = 4;
+
+ _ewmaRTT = (_ewmaRTT * (RTT_ESTIMATION_ALPHA - 1) + lastRTT) / RTT_ESTIMATION_ALPHA;
+ _rttVariance = (_rttVariance * (RTT_ESTIMATION_VARIANCE_ALPHA- 1)
+ + abs(lastRTT - _ewmaRTT)) / RTT_ESTIMATION_VARIANCE_ALPHA;
+ }
+
+ // keep track of the lowest RTT during connection
+ _baseRTT = std::min(_baseRTT, lastRTT);
+
+ // find the min RTT during the last RTT
+ _currentMinRTT = std::min(_currentMinRTT, lastRTT);
+
+ // add 1 to the number of RTT samples collected during this RTT window
+ ++_numRTTs;
+
+ return true;
+}
+
bool TCPVegasCC::onACK(SequenceNumber ack, p_high_resolution_clock::time_point receiveTime) {
- auto it = _sentPacketTimes.find(ack);
auto previousAck = _lastACK;
_lastACK = ack;
- if (it != _sentPacketTimes.end()) {
+ bool wasDuplicateACK = (ack == previousAck);
- // calculate the RTT (receive time - time ACK sent)
- int lastRTT = duration_cast(receiveTime - it->second).count();
+ auto it = std::find_if(_sentPacketDatas.begin(), _sentPacketDatas.end(), [ack](SentPacketData& packetTime){
+ return packetTime.sequenceNumber == ack;
+ });
- const int MAX_RTT_SAMPLE_MICROSECONDS = 10000000;
+ if (!wasDuplicateACK && it != _sentPacketDatas.end()) {
+ // check if we can unambigiously calculate an RTT from this ACK
- if (lastRTT < 0) {
- Q_ASSERT_X(false, __FUNCTION__, "calculated an RTT that is not > 0");
+ // for that to be the case,
+ // any of the packets this ACK covers (from the current ACK back to our previous ACK)
+ // must not have been re-sent
+ bool canBeUsedForRTT = std::none_of(_sentPacketDatas.begin(), _sentPacketDatas.end(),
+ [ack, previousAck](SentPacketData& sentPacketData)
+ {
+ return sentPacketData.sequenceNumber > previousAck
+ && sentPacketData.sequenceNumber <= ack
+ && sentPacketData.wasResent;
+ });
+
+ auto sendTime = it->timePoint;
+
+ // remove all sent packet times up to this sequence number
+ it = _sentPacketDatas.erase(_sentPacketDatas.begin(), it + 1);
+
+ // if we can use this ACK for an RTT calculation then do so
+ // returning false if we calculate an invalid RTT
+ if (canBeUsedForRTT && !calculateRTT(sendTime, receiveTime)) {
return false;
- } else if (lastRTT == 0) {
- // we do not allow a zero microsecond RTT (as per the UNIX kernel implementation of TCP Vegas)
- lastRTT = 1;
- } else if (lastRTT > MAX_RTT_SAMPLE_MICROSECONDS) {
- // we cap the lastRTT to MAX_RTT_SAMPLE_MICROSECONDS to avoid overflows in window size calculations
- lastRTT = MAX_RTT_SAMPLE_MICROSECONDS;
}
+ }
- if (_ewmaRTT == -1) {
- // first RTT sample - set _ewmaRTT to the value and set the variance to half the value
- _ewmaRTT = lastRTT;
- _rttVariance = lastRTT / 2;
- } else {
- // This updates the RTT using exponential weighted moving average
- // This is the Jacobson's forumla for RTT estimation
- // http://www.mathcs.emory.edu/~cheung/Courses/455/Syllabus/7-transport/Jacobson-88.pdf
-
- // Estimated RTT = (1 - x)(estimatedRTT) + (x)(sampleRTT)
- // (where x = 0.125 via Jacobson)
-
- // Deviation = (1 - x)(deviation) + x |sampleRTT - estimatedRTT|
- // (where x = 0.25 via Jacobson)
-
- static const int RTT_ESTIMATION_ALPHA = 8;
- static const int RTT_ESTIMATION_VARIANCE_ALPHA = 4;
-
- _ewmaRTT = (_ewmaRTT * (RTT_ESTIMATION_ALPHA - 1) + lastRTT) / RTT_ESTIMATION_ALPHA;
- _rttVariance = (_rttVariance * (RTT_ESTIMATION_VARIANCE_ALPHA- 1)
- + abs(lastRTT - _ewmaRTT)) / RTT_ESTIMATION_VARIANCE_ALPHA;
- }
-
- // add 1 to the number of ACKs during this RTT
- ++_numACKs;
-
- // keep track of the lowest RTT during connection
- _baseRTT = std::min(_baseRTT, lastRTT);
-
- // find the min RTT during the last RTT
- _currentMinRTT = std::min(_currentMinRTT, lastRTT);
-
- auto sinceLastAdjustment = duration_cast(p_high_resolution_clock::now() - _lastAdjustmentTime).count();
- if (sinceLastAdjustment >= _ewmaRTT) {
- performCongestionAvoidance(ack);
- }
-
- // remove this sent packet time from the hash
- _sentPacketTimes.erase(it);
+ auto sinceLastAdjustment = duration_cast(p_high_resolution_clock::now() - _lastAdjustmentTime).count();
+ if (sinceLastAdjustment >= _ewmaRTT) {
+ performCongestionAvoidance(ack);
}
++_numACKSinceFastRetransmit;
// perform the fast re-transmit check if this is a duplicate ACK or if this is the first or second ACK
// after a previous fast re-transmit
- if (ack == previousAck || _numACKSinceFastRetransmit < 3) {
- // we may need to re-send ackNum + 1 if it has been more than our estimated timeout since it was sent
-
- auto it = _sentPacketTimes.find(ack + 1);
- if (it != _sentPacketTimes.end()) {
-
- auto now = p_high_resolution_clock::now();
- auto sinceSend = duration_cast(now - it->second).count();
-
- if (sinceSend >= estimatedTimeout()) {
- // break out of slow start, we've decided this is loss
- _slowStart = false;
-
- // reset the fast re-transmit counter
- _numACKSinceFastRetransmit = 0;
-
- // return true so the caller knows we needed a fast re-transmit
- return true;
- }
- }
-
- // if this is the 3rd duplicate ACK, we fallback to Reno's fast re-transmit
- static const int RENO_FAST_RETRANSMIT_DUPLICATE_COUNT = 3;
-
- ++_duplicateACKCount;
-
- if (ack == previousAck && _duplicateACKCount == RENO_FAST_RETRANSMIT_DUPLICATE_COUNT) {
- // break out of slow start, we just hit loss
- _slowStart = false;
-
- // reset our fast re-transmit counters
- _numACKSinceFastRetransmit = 0;
- _duplicateACKCount = 0;
-
- // return true so the caller knows we needed a fast re-transmit
- return true;
- }
+ if (wasDuplicateACK || _numACKSinceFastRetransmit < 3) {
+ return needsFastRetransmit(ack, wasDuplicateACK);
} else {
_duplicateACKCount = 0;
}
@@ -141,6 +135,49 @@ bool TCPVegasCC::onACK(SequenceNumber ack, p_high_resolution_clock::time_point r
return false;
}
+bool TCPVegasCC::needsFastRetransmit(SequenceNumber ack, bool wasDuplicateACK) {
+ // we may need to re-send ackNum + 1 if it has been more than our estimated timeout since it was sent
+
+ auto nextIt = std::find_if(_sentPacketDatas.begin(), _sentPacketDatas.end(), [ack](SentPacketData& packetTime){
+ return packetTime.sequenceNumber == ack + 1;
+ });
+
+ if (nextIt != _sentPacketDatas.end()) {
+ auto now = p_high_resolution_clock::now();
+ auto sinceSend = duration_cast(now - nextIt->timePoint).count();
+
+ if (sinceSend >= estimatedTimeout()) {
+ // break out of slow start, we've decided this is loss
+ _slowStart = false;
+
+ // reset the fast re-transmit counter
+ _numACKSinceFastRetransmit = 0;
+
+ // return true so the caller knows we needed a fast re-transmit
+ return true;
+ }
+ }
+
+ // if this is the 3rd duplicate ACK, we fallback to Reno's fast re-transmit
+ static const int RENO_FAST_RETRANSMIT_DUPLICATE_COUNT = 3;
+
+ ++_duplicateACKCount;
+
+ if (wasDuplicateACK && _duplicateACKCount == RENO_FAST_RETRANSMIT_DUPLICATE_COUNT) {
+ // break out of slow start, we just hit loss
+ _slowStart = false;
+
+ // reset our fast re-transmit counters
+ _numACKSinceFastRetransmit = 0;
+ _duplicateACKCount = 0;
+
+ // return true so the caller knows we needed a fast re-transmit
+ return true;
+ }
+
+ return false;
+}
+
void TCPVegasCC::performCongestionAvoidance(udt::SequenceNumber ack) {
static int VEGAS_ALPHA_SEGMENTS = 4;
static int VEGAS_BETA_SEGMENTS = 6;
@@ -158,7 +195,7 @@ void TCPVegasCC::performCongestionAvoidance(udt::SequenceNumber ack) {
int64_t windowSizeDiff = (int64_t) _congestionWindowSize * (rtt - _baseRTT) / _baseRTT;
- if (_numACKs <= 2) {
+ if (_numRTTs <= 2) {
performRenoCongestionAvoidance(ack);
} else {
if (_slowStart) {
@@ -209,7 +246,7 @@ void TCPVegasCC::performCongestionAvoidance(udt::SequenceNumber ack) {
_currentMinRTT = std::numeric_limits::max();
// reset our count of collected RTT samples
- _numACKs = 0;
+ _numRTTs = 0;
}
@@ -230,29 +267,29 @@ void TCPVegasCC::performRenoCongestionAvoidance(SequenceNumber ack) {
return;
}
- int numAcked = _numACKs;
+ int numRTTCollected = _numRTTs;
if (_slowStart) {
// while in slow start we grow the congestion window by the number of ACKed packets
// allowing it to grow as high as the slow start threshold
- int congestionWindow = _congestionWindowSize + numAcked;
+ int congestionWindow = _congestionWindowSize + numRTTCollected;
if (congestionWindow > udt::MAX_PACKETS_IN_FLIGHT) {
// we're done with slow start, set the congestion window to the slow start threshold
_congestionWindowSize = udt::MAX_PACKETS_IN_FLIGHT;
// figure out how many left over ACKs we should apply using the regular reno congestion avoidance
- numAcked = congestionWindow - udt::MAX_PACKETS_IN_FLIGHT;
+ numRTTCollected = congestionWindow - udt::MAX_PACKETS_IN_FLIGHT;
} else {
_congestionWindowSize = congestionWindow;
- numAcked = 0;
+ numRTTCollected = 0;
}
}
// grab the size of the window prior to reno additive increase
int preAIWindowSize = _congestionWindowSize;
- if (numAcked > 0) {
+ if (numRTTCollected > 0) {
// Once we are out of slow start, we use additive increase to grow the window slowly.
// We grow the congestion window by a single packet everytime the entire congestion window is sent.
@@ -263,7 +300,7 @@ void TCPVegasCC::performRenoCongestionAvoidance(SequenceNumber ack) {
}
// increase the window size by (1 / window size) for every ACK received
- _ackAICount += numAcked;
+ _ackAICount += numRTTCollected;
if (_ackAICount >= preAIWindowSize) {
// when _ackAICount % preAIWindowSize == 0 then _ackAICount is 0
// when _ackAICount % preAIWindowSize != 0 then _ackAICount is _ackAICount - (_ackAICount % preAIWindowSize)
@@ -277,8 +314,19 @@ void TCPVegasCC::performRenoCongestionAvoidance(SequenceNumber ack) {
}
void TCPVegasCC::onPacketSent(int wireSize, SequenceNumber seqNum, p_high_resolution_clock::time_point timePoint) {
- if (_sentPacketTimes.find(seqNum) == _sentPacketTimes.end()) {
- _sentPacketTimes[seqNum] = timePoint;
+ _sentPacketDatas.emplace_back(seqNum, timePoint);
+}
+
+void TCPVegasCC::onPacketReSent(int wireSize, SequenceNumber seqNum, p_high_resolution_clock::time_point timePoint) {
+ // look for our information for this sent packet
+ auto it = std::find_if(_sentPacketDatas.begin(), _sentPacketDatas.end(), [seqNum](SentPacketData& sentPacketInfo){
+ return sentPacketInfo.sequenceNumber == seqNum;
+ });
+
+ // if we found information for this packet (it hasn't been erased because it hasn't yet been ACKed)
+ // then mark it as re-sent so we know it cannot be used for RTT calculations
+ if (it != _sentPacketDatas.end()) {
+ it->wasResent = true;
}
}
diff --git a/libraries/shared/src/SpatiallyNestable.cpp b/libraries/shared/src/SpatiallyNestable.cpp
index fd2ff6e790..97e20f5627 100644
--- a/libraries/shared/src/SpatiallyNestable.cpp
+++ b/libraries/shared/src/SpatiallyNestable.cpp
@@ -74,10 +74,12 @@ void SpatiallyNestable::setParentID(const QUuid& parentID) {
}
});
- bool success = false;
- auto parent = getParentPointer(success);
- if (success && parent) {
- parent->updateQueryAACube();
+ if (!_parentKnowsMe) {
+ bool success = false;
+ auto parent = getParentPointer(success);
+ if (success && parent) {
+ parent->updateQueryAACube();
+ }
}
}
diff --git a/scripts/system/commerce/wallet.js b/scripts/system/commerce/wallet.js
index fd230de0e4..641112b6b4 100644
--- a/scripts/system/commerce/wallet.js
+++ b/scripts/system/commerce/wallet.js
@@ -377,9 +377,9 @@ function deleteSendMoneyParticleEffect() {
}
function onUsernameChanged() {
- if (Account.username !== Settings.getValue("wallet/savedUsername")) {
- Settings.setValue("wallet/autoLogout", false);
- Settings.setValue("wallet/savedUsername", "");
+ if (Account.username !== Settings.getValue("keepMeLoggedIn/savedUsername")) {
+ Settings.setValue("keepMeLoggedIn", false);
+ Settings.setValue("keepMeLoggedIn/savedUsername", "");
}
}
diff --git a/libraries/networking/src/udt/TCPVegasCC.h b/libraries/networking/src/udt/TCPVegasCC.h
index bb14728d4b..1d83c4c992 100644
--- a/libraries/networking/src/udt/TCPVegasCC.h
+++ b/libraries/networking/src/udt/TCPVegasCC.h
@@ -30,6 +30,7 @@ public:
virtual void onTimeout() override {};
virtual void onPacketSent(int wireSize, SequenceNumber seqNum, p_high_resolution_clock::time_point timePoint) override;
+ virtual void onPacketReSent(int wireSize, SequenceNumber seqNum, p_high_resolution_clock::time_point timePoint) override;
virtual int estimatedTimeout() const override;
@@ -37,11 +38,23 @@ protected:
virtual void performCongestionAvoidance(SequenceNumber ack);
virtual void setInitialSendSequenceNumber(SequenceNumber seqNum) override { _lastACK = seqNum - 1; }
private:
+ bool calculateRTT(p_high_resolution_clock::time_point sendTime, p_high_resolution_clock::time_point receiveTime);
+ bool needsFastRetransmit(SequenceNumber ack, bool wasDuplicateACK);
+
bool isCongestionWindowLimited();
void performRenoCongestionAvoidance(SequenceNumber ack);
- using PacketTimeList = std::map;
- PacketTimeList _sentPacketTimes; // Map of sequence numbers to sent time
+ struct SentPacketData {
+ SentPacketData(SequenceNumber seqNum, p_high_resolution_clock::time_point tPoint)
+ : sequenceNumber(seqNum), timePoint(tPoint) {};
+
+ SequenceNumber sequenceNumber;
+ p_high_resolution_clock::time_point timePoint;
+ bool wasResent { false };
+ };
+
+ using PacketTimeList = std::vector;
+ PacketTimeList _sentPacketDatas; // association of sequence numbers to sent time, for RTT calc
p_high_resolution_clock::time_point _lastAdjustmentTime; // Time of last congestion control adjustment
@@ -56,7 +69,7 @@ private:
int _ewmaRTT { -1 }; // Exponential weighted moving average RTT
int _rttVariance { 0 }; // Variance in collected RTT values
- int _numACKs { 0 }; // Number of ACKs received during the last RTT (since last performed congestion avoidance)
+ int _numRTTs { 0 }; // Number of RTTs calculated during the last RTT (since last performed congestion avoidance)
int _ackAICount { 0 }; // Counter for number of ACKs received for Reno additive increase
int _duplicateACKCount { 0 }; // Counter for duplicate ACKs received